@@ -929,7 +929,7 @@ class ScheduledActivity(ABC):
 
     @property
     def extrapolated_priority(self):
-        return min(self.priority, min(x.priority for x in self.successors))
+        return min(self.priority, min(x.priority for x in self.successors) if len(self.successors) > 0 else self.priority)
 
     @property
     def extrapolated_target_date(self):
